@@ -80,6 +80,10 @@ int main(int argc, char* argv[])
     if (!qEnvironmentVariableIsSet("QT_IM_MODULE") || (qEnvironmentVariableIsSet("QT_IM_MODULE") && qgetenv("QT_IM_MODULE") != QByteArrayLiteral("maliit"))) {
         qputenv("QT_IM_MODULE", QByteArrayLiteral("qtvirtualkeyboard"));
     }
+
+    // Suppresses modal warnings about unwritable configuration files which may render the system inaccessible
+    qputenv("KDE_HOME_READONLY", "1");
+
     ScreenLocker::UnlockApp app(argc, argv);
     app.setQuitOnLastWindowClosed(false);
     QCoreApplication::setApplicationName(QStringLiteral("kscreenlocker_greet"));
